flask-geckoboard
=================

Geckoboard_ is a hosted, real-time status board serving up indicators
from web analytics, CRM, support, infrastructure, project management,
sales, etc.  It can be connected to virtually any source of quantitative
data.

This Flask extension provides view decorators to help create custom
widgets.  This is under active refactoring from `django-geckoboard`_ so you
will need to use Git to get the development version from the `project page`_::

    $ git clone git://github.com/PolymathVentures/flask-geckoboard.git

See the ``geckoboard`` package docstring for documentation.

If you want to help out with the development of flask-geckoboard, by
posting detailed bug reports, proposing new features or other analytics
services to support, or suggesting documentation improvements, please
use the `issue tracker`_.  If you want to get your hands dirty, great!
Clone the repository, make changes and send a pull request.  Please do
create an issue to discuss your plans.  People who have contributed:

From `django-geckoboard`_:

* Joost Cassee
* Simon de Haan
* Hedley Roos
* Arthur Furlan
* Jeremy A. Johnson
* Rob Hudson

Copyright (C) 2011-2014 Rob Eroh  <rob|at|eroh|dot|me> and others.
This software is licensed under the MIT License (see LICENSE.txt).

Thanks go to Geckoboard for their support, and to GitHub for hosting the
project source code and issue tracker.

.. _Flask: http://flask.pocoo.org/
.. _Geckoboard: http://www.geckoboard.com/
.. _`project page`: http://github.com/PolymathVentures/flask-geckoboard
.. _`issue tracker`: http://github.com/PolymathVentures/flask-geckoboard/issues
.. _`django-geckoboard`: https://github.com/jcassee/django-geckoboard
